unit MainForm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, CLKConst;

type
  TfrmMain = class(TForm)
    btTestLock: TButton;
    btShowRegInfo: TButton;
    edStoreDate: TEdit;
    laStoreData: TLabel;
    edRestoredData: TEdit;
    laRestoredData: TLabel;
    btStoreRestore: TButton;
    procedure btTestLockClick(Sender: TObject);
    procedure btShowRegInfoClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure btStoreRestoreClick(Sender: TObject);
  private
    { Private declarations }
    DLLHandle : Integer;
    DLLFile : string;
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation
{$R *.dfm}
//This line, adds Colock library (CLK.dll) to your executable file as a resource
{$R HiddenDLL.RES}

procedure TfrmMain.btTestLockClick(Sender: TObject);
var
  CLKResult : Integer;
  CLKPathStr : string;
  CLKPathP: PAnsiChar;
  //function cCheckLock(AppName, ParamFile, ParamEncPass : PChar; ParamEncMethod : Integer; HardwareIDMethod : Integer) : Integer; stdcall;
  CLKCHK : function (AppName, ParamFile, ParamEncPass : PAnsiChar; ParamEncMethod : Integer; HardwareIDMethod : Integer) : Integer ; stdcall;
begin
  //If Clk.dll is not loaded then exit
  if DLLHandle = 0 then
    Exit;
  //Let CLKCHK point to cCheckLock function
  @CLKCHK := GetProcAddress(DLLHandle, 'cCheckLock');
  //Get the full path of parameters file
  CLKPathStr := ExtractFilePath(Application.ExeName) + 'CoLockTest.clk';
  GetMem(CLKPathP, Length(CLKPathStr) + 1);
  ZeroMemory(CLKPathP, Length(CLKPathStr) + 1);
  //Store parameters file path into CLKPathP variable
  StrPCopy(CLKPathP, CLKPathStr);
  //Run cCheckLock function
  if Assigned(CLKCHK) then
    CLKResult := CLKCHK('CoLockTest', CLKPathP, '87654321', 2, 1);
  @CLKCHK := nil;

  FreeMem(CLKPathP, Length(CLKPathStr) + 1);
  CLKPathP := nil;

  //Check the result
  case CLKResult of
    Const_Successful : MessageBox(0, 'Successful Activation.', 'Info', MB_OK + MB_ICONINFORMATION);
    Const_InvalidActivationCode : MessageBox(0, 'Invalid Activation Code!', 'Error', MB_OK + MB_ICONERROR);
    Const_IniFileNotFound : MessageBox(0, 'Lock Configuration File not found!', 'Error', MB_OK + MB_ICONERROR);
    Const_UserCanceledActivation, Const_EmptyUserActivationCode : {Do Nothing};
  else
    MessageBox(0, 'Error in activation!', 'Error', MB_OK + MB_ICONERROR);
  end;
end;

procedure TfrmMain.btShowRegInfoClick(Sender: TObject);
var
  SLWResult : Integer;
  //function ShowLockWindow(AppName, ParamFile, ParamEncPass : PChar; ParamEncMethod : Integer; OptionalMessage : PChar; HardwareIDMethod : Integer) : Integer; stdcall;
  SLW : function (AppName, ParamFile, ParamEncPass : PAnsiChar; ParamEncMethod : Integer; OptionalMessage : PAnsiChar; HardwareIDMethod : Integer) : Integer; stdcall;
begin
  //If Clk.dll is not loaded then exit
  if DLLHandle = 0 then
    Exit;
  //Let SLW point to ShowLockWindow function
  @SLW := GetProcAddress(DLLHandle, 'ShowLockWindow');
  //Run ShowLockWindow function
  if Assigned(SLW) then
    SLWResult := SLW('CoLockTest', 'CoLockTest.clk', '87654321', 2, '', 1);
  @SLW := nil;
end;

procedure TfrmMain.FormCreate(Sender: TObject);
  function GenerateRandomString(StringLength : Integer) : string;
    var
      I : Integer;
      ARandomAsciiCode : Integer;
      ARandomChar : Char;
    begin
      Result := '';
      Randomize;
      for I := 1 to StringLength do
        begin
          ARandomAsciiCode := Ord('A') + Random(Ord('Z') - Ord('A'));
          ARandomChar := Chr(ARandomAsciiCode);
          Result := Result + ARandomChar;
        end;
    end;

  function GetTempDir: string;
  var
     lng: DWORD;
     thePath: string;
  begin
    SetLength(thePath, MAX_PATH) ;
    lng := GetTempPath(MAX_PATH, PChar(thePath)) ;
    SetLength(thePath, lng) ;
    Result := thePath;
  end;

var
  Res : TResourceStream;
begin
  //Extract Clk.dll from resource and rename it to a file with a random name
  Res := TResourceStream.Create(hInstance, 'CLKDLL', PChar('DLL'));
  DLLFile := GetTempDir + GenerateRandomString(8) + '.DLL';
  //Ensure that there is not a file with similar name in system folder
  while FileExists(DLLFile) do
    DLLFile := GetTempDir + GenerateRandomString(8) + '.DLL';
  //Save Clk.dll in system folder
  try
    Res.SavetoFile(DLLFile);
    Res.Free;
    Res := nil;
  except
    MessageBox(0, 'Unable to Copy Lock DLL!', 'Error', MB_OK + MB_ICONERROR);
    Exit;
  end;
  //Load Clk.dll into memory
  DLLHandle := LoadLibrary(PChar(DLLFile));
  if DLLHandle = 0 then
    MessageBox(0, 'Unable to load Lock DLL!', 'Error', MB_OK + MB_ICONERROR);
end;

procedure TfrmMain.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  //Unload Clk.dll and delete it from system folder
  if DLLHandle <> 0 then
    begin
      FreeLibrary(DLLHandle);
      DLLHandle := 0;
    end;
  if FileExists(DLLFile) then
    DeleteFile(DLLFile);
end;

procedure TfrmMain.btStoreRestoreClick(Sender: TObject);
var
  SEPSResult : Integer;
  StoreDataStr: string;
  StoreDataP: PAnsiChar;
  //function StoreExParamStr(ParamFile : PChar; ParamEncPass : PChar; ParamEncMethod : Integer; ParName : PChar; ParValue : PChar) : Integer; stdcall;
  SEPS : function (ParamFile : PAnsiChar; ParamEncPass : PAnsiChar; ParamEncMethod : Integer; ParName : PAnsiChar; ParValue : PAnsiChar) : Integer; stdcall;
  //  function RestoreExParamStr(ParamFile : PAnsiChar; ParamEncPass : PAnsiChar; ParamEncMethod : Integer; ParName : PAnsiChar) : PAnsiChar; stdcall;
  REPS : function (ParamFile : PAnsiChar; ParamEncPass : PAnsiChar; ParamEncMethod : Integer; ParName : PAnsiChar) : PAnsiChar; stdcall;
begin
  //If Clk.dll is not loaded then exit
  if DLLHandle = 0 then
    Exit;
  //Let SEPS point to StoreExParamStr function
  @SEPS := GetProcAddress(DLLHandle, 'StoreExParamStr');
  StoreDataStr := edStoreDate.Text;
  GetMem(StoreDataP, Length(StoreDataStr) + 1);
  ZeroMemory(StoreDataP, Length(StoreDataStr) + 1);
  StrPCopy(StoreDataP, StoreDataStr);
  //Run StoreExParamStr function
  if Assigned(SEPS) then
    SEPSResult := SEPS('CoLockTest.clk', '87654321', 2, 'TestKey', StoreDataP);
  @SEPS := nil;
  FreeMem(StoreDataP, Length(StoreDataStr) + 1);
  StoreDataP := nil;

  @REPS := GetProcAddress(DLLHandle, 'RestoreExParamStr');
  //Run RestoreExParamStr function
  if Assigned(REPS) then
    edRestoredData.Text := REPS('CoLockTest.clk', '87654321', 2, 'TestKey');
  @REPS := nil;
end;

end.
